@@ -26,7 +26,7 @@ const rootSshAccessOptions = [
 ];
 
 const HeWizardVm = ({appliances, applPathSelection, collapsibleSections, cpuArch, deploymentType, errorMsg, errorMsgs,
-                        gatewayState, interfaces, handleDnsAddressUpdate, handleDnsAddressDelete,
+                        gatewayState, getCidrErrorMsg, interfaces, handleDnsAddressUpdate, handleDnsAddressDelete,
                         handleImportApplianceUpdate, handleVmConfigUpdate, handleCollapsibleSectionChange, heSetupModel,
                         importAppliance, showApplPath, verifyDns, verifyReverseDns, warningMsgs}) => {
     const vmConfig = heSetupModel.vm;
@@ -45,6 +45,8 @@ const HeWizardVm = ({appliances, applPathSelection, collapsibleSections, cpuArch
     advancedSectionIconClasses += collapsibleSections["advanced"] ? "fa-angle-right" : "fa-angle-down";
     const advancedSectionClasses = collapsibleSections["advanced"] ? "collapse" : "";
 
+    const cidrPrefixClasses = errorMsgs["cloudinitVMStaticCIDRPrefix"] ? "form-group has-error" : "form-group nested-input";
+
     return (
         <div>
             <form className="form-horizontal he-form-container">
@@ -171,14 +173,21 @@ const HeWizardVm = ({appliances, applPathSelection, collapsibleSections, cpuArch
                                    className="form-control"
                                    value={vmConfig.cloudinitVMStaticCIDR.value}
                                    onChange={(e) => handleVmConfigUpdate("cloudinitVMStaticCIDR", e.target.value, "vm")}
-                                   onBlur={(e) => verifyReverseDns(e.target.value)}
-                            />&nbsp;/&nbsp;
-                            <input type="text" style={{width: "40px", display: "inline-block"}}
-                                   placeholder="24"
-                                   className="form-control"
-                                   value={vmConfig.cloudinitVMStaticCIDRPrefix.value}
-                                   onChange={(e) => handleVmConfigUpdate("cloudinitVMStaticCIDRPrefix", e.target.value, "vm")} />
-                            {errorMsgs.cloudinitVMStaticCIDR && <span className="help-block">{errorMsgs.cloudinitVMStaticCIDR}</span>}
+                                   onBlur={(e) => verifyReverseDns(e.target.value)} />
+                            &nbsp;/&nbsp;
+                            <span className={cidrPrefixClasses} id="he-wizard-cidr-container">
+                                <input id="he-wizard-cidr"
+                                       type="text"
+                                       placeholder="24"
+                                       className="form-control"
+                                       value={vmConfig.cloudinitVMStaticCIDRPrefix.value}
+                                       onChange={(e) => handleVmConfigUpdate("cloudinitVMStaticCIDRPrefix", e.target.value, "vm")} />
+                            </span>
+                            {(errorMsgs.cloudinitVMStaticCIDRPrefix || errorMsgs.cloudinitVMStaticCIDR) &&
+                                <span className="has-error">
+                                    <span className="help-block">{getCidrErrorMsg()}</span>
+                                </span>
+                            }
                         </div>
                     </div>
 
@@ -210,7 +219,11 @@ const HeWizardVm = ({appliances, applPathSelection, collapsibleSections, cpuArch
                                                           rowLimit={3}
                                                           handleValueUpdate={handleDnsAddressUpdate}
                                                           handleValueDelete={handleDnsAddressDelete}/>
-                                {errorMsgs.cloudinitVMDNS && <span className="help-block">{errorMsgs.cloudinitVMDNS}</span>}
+                                {errorMsgs.cloudinitVMDNS &&
+                                    <span className="help-block" id="he-wizard-dns-error-container">
+                                        {errorMsgs.cloudinitVMDNS}
+                                    </span>
+                                }
                             </div>
                         </div>
                     </div>
@@ -311,7 +324,7 @@ const HeWizardVm = ({appliances, applPathSelection, collapsibleSections, cpuArch
                 {isOtopiDeployment &&
                     <div className="form-group">
                         <label className="col-md-3 control-label">Use Cloud-Init &nbsp;
-                            <i className="pficon pficon-info info-icon" rel="tooltip"
+                            <i className="pficon pficon-info he-wizard-info-icon" rel="tooltip"
                                title="Use cloud-init to customize the appliance on the first boot" />
                         </label>
                         <div className="col-md-3">
@@ -362,8 +375,8 @@ const HeWizardVm = ({appliances, applPathSelection, collapsibleSections, cpuArch
                         </div>
 
                         <div className="form-group">
-                            <label className="col-md-3 control-label">Edit Hosts File &nbsp;
-                                <i className="pficon pficon-info info-icon" rel="tooltip" id="hosts_file"
+                            <label className="col-md-3 control-label">Edit Hosts File
+                                <i className="pficon pficon-info he-wizard-info-icon" rel="tooltip" id="hosts_file"
                                    title="Add lines for the appliance itself and for this host to /etc/hosts on the engine VM?
                                               Note: ensuring that this host could resolve the engine VM hostname is still up to you."
                                 />
@@ -410,8 +423,8 @@ const HeWizardVm = ({appliances, applPathSelection, collapsibleSections, cpuArch
                         {isOtopiDeployment &&
                             <span>
                                 <div className="form-group">
-                                    <label className="col-md-3 control-label">Engine Setup &nbsp;
-                                        <i className="pficon pficon-info info-icon" rel="tooltip" id="engine_setup"
+                                    <label className="col-md-3 control-label">Engine Setup
+                                        <i className="pficon pficon-info he-wizard-info-icon" rel="tooltip" id="engine_setup"
                                            title="Automatically execute engine-setup on the first boot" />
                                     </label>
                                     <div className="col-md-1">
@@ -423,8 +436,8 @@ const HeWizardVm = ({appliances, applPathSelection, collapsibleSections, cpuArch
                                 </div>
 
                                 <div className="form-group">
-                                    <label className="col-md-3 control-label">Engine Restart &nbsp;
-                                        <i className="pficon pficon-info info-icon" rel="tooltip" id="engine_restart"
+                                    <label className="col-md-3 control-label">Engine Restart
+                                        <i className="pficon pficon-info he-wizard-info-icon" rel="tooltip" id="engine_restart"
                                            title="Automatically restart the engine VM as a monitored service after engine-setup" />
                                     </label>
                                     <div className="col-md-1">
